inputvalidation

package
v0.0.0-...-c3b309f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 18, 2021 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package inputvalidation implements additional functions to validate input given to the web client.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ValidateByteLink(byteLink string) error

ValidateByteLink checks if the given byte-link is of proper format.

func ValidateCustomLink(customLink string) error

ValidateCustomLink checks if the given custom link is of proper format.

func ValidateSourceLink(sourceLink string) error

ValidateSourceLink checks if the given source link is of proper format.

Types

This section is empty.

Jump to