Documentation
¶
Overview ¶
Package inputvalidation implements additional functions to validate input given to the web client.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ValidateByteLink ¶
ValidateByteLink checks if the given byte-link is of proper format.
func ValidateCustomLink ¶
ValidateCustomLink checks if the given custom link is of proper format.
func ValidateSourceLink ¶
ValidateSourceLink checks if the given source link is of proper format.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.